==> zio-aws-ec2_2.13-5.17.104.7-sources.jar: zio/aws/ec2/model/DescribeSnapshotAttributeRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.SnapshotId
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DescribeSnapshotAttributeRequest(
    attribute: zio.aws.ec2.model.SnapshotAttributeName,
    snapshotId: SnapshotId
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DescribeSnapshotAttributeRequest = {
    import DescribeSnapshotAttributeRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DescribeSnapshotAttributeRequest
      .builder()
      .attribute(attribute.unwrap)
      .snapshotId(SnapshotId.unwrap(snapshotId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.DescribeSnapshotAttributeRequest.ReadOnly =
    zio.aws.ec2.model.DescribeSnapshotAttributeRequest.wrap(buildAwsValue())
}
object DescribeSnapshotAttributeRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DescribeSnapshotAttributeRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DescribeSnapshotAttributeRequest =
      zio.aws.ec2.model.DescribeSnapshotAttributeRequest(attribute, snapshotId)
    def attribute: zio.aws.ec2.model.SnapshotAttributeName
    def snapshotId: SnapshotId
    def getAttribute
        : ZIO[Any, Nothing, zio.aws.ec2.model.SnapshotAttributeName] =
      ZIO.succeed(attribute)
    def getSnapshotId: ZIO[Any, Nothing, SnapshotId] = ZIO.succeed(snapshotId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DescribeSnapshotAttributeRequest
  ) extends zio.aws.ec2.model.DescribeSnapshotAttributeRequest.ReadOnly {
    override val attribute: zio.aws.ec2.model.SnapshotAttributeName =
      zio.aws.ec2.model.SnapshotAttributeName.wrap(impl.attribute())
    override val snapshotId: SnapshotId =
      zio.aws.ec2.model.primitives.SnapshotId(impl.snapshotId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DescribeSnapshotAttributeRequest
  ): zio.aws.ec2.model.DescribeSnapshotAttributeRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-ec2_2.13-7.21.15.12-sources.jar: zio/aws/ec2/model/DescribeSnapshotAttributeRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.SnapshotId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DescribeSnapshotAttributeRequest(
    attribute: zio.aws.ec2.model.SnapshotAttributeName,
    snapshotId: SnapshotId,
    dryRun: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DescribeSnapshotAttributeRequest = {
    import DescribeSnapshotAttributeRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DescribeSnapshotAttributeRequest
      .builder()
      .attribute(attribute.unwrap)
      .snapshotId(SnapshotId.unwrap(snapshotId): java.lang.String)
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.DescribeSnapshotAttributeRequest.ReadOnly =
    zio.aws.ec2.model.DescribeSnapshotAttributeRequest.wrap(buildAwsValue())
}
object DescribeSnapshotAttributeRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DescribeSnapshotAttributeRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DescribeSnapshotAttributeRequest =
      zio.aws.ec2.model.DescribeSnapshotAttributeRequest(
        attribute,
        snapshotId,
        dryRun.map(value => value)
      )
    def attribute: zio.aws.ec2.model.SnapshotAttributeName
    def snapshotId: SnapshotId
    def dryRun: Optional[Boolean]
    def getAttribute
        : ZIO[Any, Nothing, zio.aws.ec2.model.SnapshotAttributeName] =
      ZIO.succeed(attribute)
    def getSnapshotId: ZIO[Any, Nothing, SnapshotId] = ZIO.succeed(snapshotId)
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DescribeSnapshotAttributeRequest
  ) extends zio.aws.ec2.model.DescribeSnapshotAttributeRequest.ReadOnly {
    override val attribute: zio.aws.ec2.model.SnapshotAttributeName =
      zio.aws.ec2.model.SnapshotAttributeName.wrap(impl.attribute())
    override val snapshotId: SnapshotId =
      zio.aws.ec2.model.primitives.SnapshotId(impl.snapshotId())
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DescribeSnapshotAttributeRequest
  ): zio.aws.ec2.model.DescribeSnapshotAttributeRequest.ReadOnly = new Wrapper(
    impl
  )
}
